"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const cli_utils_1 = require("@ionic/cli-utils");
const command_1 = require("@ionic/cli-utils/lib/command");
const serve_1 = require("@ionic/cli-utils/lib/serve");
class DocsCommand extends command_1.Command {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'docs',
                type: 'global',
                description: 'Open the Ionic documentation website',
                options: [
                    {
                        name: 'browser',
                        description: `Specifies the browser to use (${serve_1.BROWSERS.map(b => chalk_1.default.green(b)).join(', ')})`,
                        aliases: ['w'],
                        groups: [cli_utils_1.OptionGroup.Advanced],
                    },
                ],
            };
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { createRequest } = yield Promise.resolve().then(() => require('@ionic/cli-utils/lib/http'));
            const browser = options['browser'] ? String(options['browser']) : undefined;
            const opn = yield Promise.resolve().then(() => require('opn'));
            const docsHomepage = 'https://ionicframework.com/docs';
            let url = docsHomepage;
            if (this.env.project.type) {
                if (this.env.project.type === 'ionic1') {
                    url = 'https://ionicframework.com/docs/v1/';
                }
                else if (this.env.project.type === 'ionic-angular') {
                    url = 'https://ionicframework.com/docs/api'; // TODO: can know framework version, HEAD request, etc
                }
            }
            try {
                const { req } = yield createRequest(this.env.config, 'head', url);
                yield req;
            }
            catch (e) {
                if (cli_utils_1.isSuperAgentError(e)) {
                    if (e.response.status === 404) {
                        this.env.log.warn(`Docs not found for your specific version of Ionic. Directing you to latest docs.`);
                        opn(`${docsHomepage}/api`, { wait: false });
                        return;
                    }
                }
                throw e;
            }
            yield opn(url, { app: browser, wait: false });
            this.env.log.ok('Launched Ionic docs in your browser!');
        });
    }
}
exports.DocsCommand = DocsCommand;
